package com.ruoyi.szxc.service;

import java.util.List;
import com.ruoyi.szxc.domain.SzxcGyApply;

/**
 * 公益报名情况Service接口
 * 
 * @author hs
 * @date 2024-03-20
 */
public interface ISzxcGyApplyService 
{
    /**
     * 查询公益报名情况
     * 
     * @param id 公益报名情况主键
     * @return 公益报名情况
     */
    public SzxcGyApply selectSzxcGyApplyById(Long id);

    /**
     * 查询公益报名情况列表
     * 
     * @param szxcGyApply 公益报名情况
     * @return 公益报名情况集合
     */
    public List<SzxcGyApply> selectSzxcGyApplyList(SzxcGyApply szxcGyApply);

    /**
     * 新增公益报名情况
     * 
     * @param szxcGyApply 公益报名情况
     * @return 结果
     */
    public int insertSzxcGyApply(SzxcGyApply szxcGyApply);

    /**
     * 修改公益报名情况
     * 
     * @param szxcGyApply 公益报名情况
     * @return 结果
     */
    public int updateSzxcGyApply(SzxcGyApply szxcGyApply);

    /**
     * 批量删除公益报名情况
     * 
     * @param ids 需要删除的公益报名情况主键集合
     * @return 结果
     */
    public int deleteSzxcGyApplyByIds(Long[] ids);

    /**
     * 删除公益报名情况信息
     * 
     * @param id 公益报名情况主键
     * @return 结果
     */
    public int deleteSzxcGyApplyById(Long id);
}
